@@ -2,7 +2,6 @@
 #' @title Outlier
 #' @param x  input data frame
 #' @keywords internal
-#' @export
 
 ## Hardcoding for column order should be removed from these
 
@@ -15,9 +14,9 @@ outlier <- function(x)
 	iterations <- ncol(x)-2
 	for (i in 1:iterations)
 	{
-	lm <- lm(x[,i+2] ~ x[,2], data=x)
+	lm <- stats::lm(x[,i+2] ~ x[,2], data=x)
  	outputmatrix[i+1,1] <- colnames(x[i+2])
- 	outputmatrix[i+1,2] <- outlierTest(lm)$bonf.p[1]
+ 	outputmatrix[i+1,2] <- car::outlierTest(lm)$bonf.p[1]
 	}
 	return(outputmatrix)
 }
